/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.uniffle.coordinator.web.resource;

import org.apache.hbase.thirdparty.javax.ws.rs.Path;
import org.apache.hbase.thirdparty.javax.ws.rs.Produces;
import org.apache.hbase.thirdparty.javax.ws.rs.core.MediaType;

@Path("api")
@Produces({MediaType.APPLICATION_JSON})
public class APIResource {
  @Path("server")
  public Class<ServerResource> getServerResource() {
    return ServerResource.class;
  }

  @Path("admin")
  public Class<AdminResource> getAdminResource() {
    return AdminResource.class;
  }

  @Path("coordinator")
  public Class<CoordinatorServerResource> getCoordinatorServerResource() {
    return CoordinatorServerResource.class;
  }

  @Path("app")
  public Class<ApplicationResource> getApplicationResource() {
    return ApplicationResource.class;
  }
}
